﻿using CoreGraphics;
using Foundation;
using Steema.TeeChart;
using Steema.TeeChart.Styles;
using System;
using UIKit;

namespace TeeChartTestApp
{
    public partial class ViewController : UIViewController
    {
        private TChart tChart;

        public ViewController (IntPtr handle) : base (handle)
        {
        }

        public override void ViewDidLoad ()
        {
            base.ViewDidLoad ();

            tChart = new TChart();
            tChart.Aspect.View3D = false;
            tChart.Aspect.ClipPoints = true;
            tChart.Panel.Gradient.Visible = false;
            tChart.Panel.MarginUnits = PanelMarginUnits.Percent;
            tChart.Panel.MarginLeft = 5;
            tChart.Panel.MarginRight = 5;
            tChart.Legend.Visible = false;
            tChart.Panning.Allow = ScrollModes.None;
            tChart.Panning.Active = true;
            tChart.Zoom.Active = false;
            tChart.Zoom.Allow = false;

            //Axes style
            tChart.Axes.Left.Labels.Style = Steema.TeeChart.AxisLabelStyle.None;
            tChart.Axes.Left.Grid.Centered = true;
            tChart.Axes.Left.SetMinMax(-5, 5);

            tChart.Axes.Bottom.Increment = Steema.TeeChart.Utils.GetDateTimeStep(DateTimeSteps.OneDay);
            tChart.Axes.Bottom.MaximumOffset = 1;
            tChart.Axes.Bottom.Labels.Style = Steema.TeeChart.AxisLabelStyle.Value;
            tChart.Axes.Bottom.MinorTicks.Visible = false;
            tChart.Axes.Bottom.Labels.Font.Size = 10;
            tChart.Axes.Bottom.Labels.DateTimeFormat = "ddd\ndd-MM";
            tChart.Axes.Bottom.SetMinMax(new DateTime(2019, 3, 4), new DateTime(2019, 3, 10, 23, 59, 59));
            
            //Uncomment to restore axis grid in v2018
            //tChart.Axes.Bottom.Grid.DrawEvery = 1;
            //tChart.Axes.Bottom.Grid.Visible = true;

            //Title
            tChart.Chart.Title.Text = "Vacation schedule";
            tChart.Chart.Title.Font.Size = 12;
            tChart.Chart.Title.Alignment = CoreText.CTTextAlignment.Center;
            tChart.Chart.Title.TextAlign = CoreText.CTTextAlignment.Center;


            tChart.Series.Clear(); //Clear any previously added series

            //Add Gantt series
            Gantt vacationGantt = new Gantt(tChart.Chart);

            vacationGantt.Transparency = 0;
            vacationGantt.Marks.Visible = true;
            vacationGantt.Marks.OnTop = true;
            vacationGantt.Marks.Font.Size = 13;
            vacationGantt.Marks.Brush.Visible = false;
            vacationGantt.Marks.Pen.Visible = false;
            vacationGantt.Marks.Arrow.Visible = false;
            vacationGantt.Marks.Clip = true;
            vacationGantt.Marks.SoftClip = false;
            vacationGantt.Marks.AutoSize = true;
            vacationGantt.Marks.Transparency = 0;

            vacationGantt.Pointer.VertSize = 13;

            vacationGantt.HorizAxis = Steema.TeeChart.Styles.HorizontalAxis.Bottom;

            vacationGantt.Add(new DateTime(2019,3,5),new DateTime(2019,3,7), 0, "Bob Adams", System.Drawing.Color.Beige);

            View.AddSubview(tChart);
        }

        public override void ViewWillLayoutSubviews()
        {
            base.ViewWillLayoutSubviews();
            tChart.Frame = new CGRect(0, 0, View.Bounds.Size.Width, View.Bounds.Size.Height);
        }
    }
}